@@ -1,7 +1,7 @@
 # ABSTRACT: Diffbot Perl API
 package WebService::Diffbot;
 {
-  $WebService::Diffbot::VERSION = '0.002';
+  $WebService::Diffbot::VERSION = '0.003';
 }
 
 use Moo;
@@ -72,6 +72,23 @@ __END__
 
 =pod
 
+=encoding UTF-8
+
+=head1 NAME
+
+WebService::Diffbot - Diffbot Perl API
+
+=head1 VERSION
+
+version 0.003
+
+=head1 DESCRIPTION
+
+This is the (unofficial) Diffbot Perl API - see http://www.diffbot.com for
+more info.
+
+Warning, currently it supports only the Article and Frontpage API (v2).
+
 =head1 SYNOPSYS
 
     use WebService::Diffbot;
@@ -99,15 +116,19 @@ __END__
     print "text:  $article->{text}";
     ...
 
-=head1 DESCRIPTION
-
-This is the (unofficial) Diffbot Perl API - see http://www.diffbot.com for
-more info.
-
-Warning, currently it supports only the Article and Frontpage API (v2).
-
 =head1 SEE ALSO
 
 L<Net::DiffBot> for old API
 
+=head1 AUTHOR
+
+Cesare Gargano <garcer@cpan.org>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2014 by Cesare Gargano.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
 =cut
